@@ -3,5 +3,5 @@ import os
 
 if __name__ == '__main__':
     path = str(os.getcwd()) + "/"
-    executable = "runFineGrainedExample.py"
-    launch(["localhost"], 10, path, executable)
+    executable = "runCoarseGrainedExample.py"
+    launch(["localhost"], 20, path, executable)
