@@ -30,7 +30,6 @@ class GeneticAlgorithmBase(object):
                         np.random.randint(2,
                             size=self._chromosome_size)))
 
-    @log_method()
     def _crossover(self, father, mother):
         """
         Exchange the random number of bits
@@ -43,8 +42,8 @@ class GeneticAlgorithmBase(object):
             mother[i] = father[i]
         for i in range(cross, self._chromosome_size):
             father[i] = mother[i]
+        return father, mother
 
-    @log_method()
     def _mutation(self, chromosome):
         """
         Invert one random bit based on probability
@@ -53,27 +52,36 @@ class GeneticAlgorithmBase(object):
         if np.random.choice([True, False], p=[0.1, 0.9]):
             rnd = random.randint(0, self._chromosome_size - 1)
             chromosome[rnd] = abs(chromosome[rnd] - 1)
+        return chromosome
 
-    @log_method()
     def _choose_individuals_based_on_fitness(self, evaluation_data):
-        fitness_max = evaluation_data.sort_objects().pop(0).fit
+        ultimate_min = 0
+        ultimate_prob = 1
+        individuals_to_choose_from = evaluation_data.sort_objects()
+        best_individual = individuals_to_choose_from.pop(0)
+        fitness_min = best_individual.fit
         chromosomes_reproducing = self._Individuals()
-        best_individual = None
+        chromosomes_reproducing.append_object(best_individual)
 
-        for chromosome_data in evaluation_data.individuals:
+        if best_individual.fit == ultimate_min:
+            chromosomes_reproducing.best_individual = best_individual
+            return chromosomes_reproducing
+        # at least two individuals are required to reproduce
+        for chromosome_data in individuals_to_choose_from:
             # best individual has 100% probability to reproduce
             # others probability is relative to his
             # weak individuals are replaced with new ones
-            prob = chromosome_data.fit / fitness_max
-            # retrieve best individual, others are randomly selected
-            if int(prob) == 1 and best_individual is None:
-                logger.info("BEST")
-                best_individual = chromosome_data.chromosome
-                chromosomes_reproducing.append_object(self._Individual(chromosome_data.fit,
-                                                                       best_individual))
-            elif np.random.choice([True, False], p=[prob, 1 - prob]):
+
+            # this is because of division by zero
+            if chromosome_data.fit == ultimate_min:
+                prob = ultimate_prob
+            else:
+                prob = fitness_min / chromosome_data.fit
+
+            if np.random.choice([True, False], p=[prob, 1 - prob]):
                 chromosomes_reproducing.append_object(self._Individual(chromosome_data.fit,
                                                                        chromosome_data.chromosome))
+        logger.info("LEN is " + str(len(chromosomes_reproducing.individuals)))
         return chromosomes_reproducing
 
     class _Individual(object):
@@ -104,6 +112,15 @@ class GeneticAlgorithmBase(object):
         def __init__(self):
             self._objects = {}
             self._individuals = []
+            self._best_individual = None
+
+        @property
+        def best_individual(self):
+            return self._best_individual
+
+        @best_individual.setter
+        def best_individual(self, individual):
+            self._best_individual = individual
 
         @property
         def individuals(self):
@@ -122,7 +139,7 @@ class GeneticAlgorithmBase(object):
             self._objects[source].add_individual(individual)
 
         def sort_objects(self):
-            return sorted(self._individuals, key=lambda x: x.fit, reverse=True)
+            return sorted(self._individuals, key=lambda x: x.fit, reverse=False)
 
         def size_of_col(self, source):
             if int(source) not in self._objects:
