@@ -20,7 +20,7 @@ class Messenger(threading.Thread):
     messages that have been sent and if they've been confirmed by RabbitMQ.
 
     """
-    PUBLISH_INTERVAL = 0.1
+    PUBLISH_INTERVAL = 0
 
     def __init__(self, server_user, server_password, server_ip_addr, exchange, exchange_type,
                  queue, subscription_routing_keys,
@@ -240,8 +240,8 @@ class Messenger(threading.Thread):
         message to be delivered in PUBLISH_INTERVAL seconds.
 
         """
-        logger.info('Scheduling next message for %0.1f seconds',
-                    self.PUBLISH_INTERVAL)
+        #logger.info('Scheduling next message for %0.1f seconds',
+        #            self.PUBLISH_INTERVAL)
         self._connection.add_timeout(self.PUBLISH_INTERVAL,
                                      self.publish_message)
 
@@ -277,7 +277,7 @@ class Messenger(threading.Thread):
                                     data, properties)
         self._message_number += 1
         self._deliveries.append(self._message_number)
-        logger.info('Published message # %i', self._message_number)
+        logger.info('Published message # %i', str(data))
         self.schedule_next_message()
 
     def add_on_cancel_callback(self):
@@ -315,12 +315,11 @@ class Messenger(threading.Thread):
         :param str|unicode body: The message body
 
         """
-        #logger.info('Received message # %s from %s: %s',
-        #            basic_deliver.delivery_tag, properties.app_id, body)
-
-        received = jsonpickle.decode(body)
-        if received is not None:
-            if received.message_type is geneticGrainedBase.MessageType.DATA:
+        logger.info('Received message # %s from %s: %s',
+                    basic_deliver.delivery_tag, properties.app_id, body)
+        if body is not None:
+            received = jsonpickle.decode(str(body))
+            if received is not None:
                 self._consumed_messages.add_message(received.generation, received)
 
         self.acknowledge_message(basic_deliver.delivery_tag)
